@@ -1,8 +1,14 @@
 # pyright: reportGeneralTypeIssues=false
+# pyright: reportGeneralTypeIssues=false
+# pyright: reportUnknownVariableType=false
+# pyright: reportUnknownParameterType=false
+# pyright: reportUnknownArgumentType=false
+# pyright: reportUnknownMemberType=false
+# pyright: reportMissingParameterType=false
 import threading
 from typing import Optional
 import websocket # type: ignore
-from jacdac.bus import Transport
+from jacdac.transport import Transport
 
 
 class WebSocketTransport(Transport):
